class commonResp {
  late var sequence;
  late var returnCode;
  late var returnMsg;

  commonResp();

  commonResp.fromJson(Map<String, dynamic> json)
      : sequence = json['sequence'],
        returnCode = json['returnCode'],
        returnMsg = json['returnMsg'];
}

class getUUIDResp extends commonResp{
  var cnts;
  var device_uuid;
  var device_id;

  getUUIDResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        device_uuid = json['returnData']['device_uuid'],
        device_id = json['returnData']['device_id'],
        super.fromJson(json);
}

class infoUpdateResp extends commonResp{
  var cnts;
  var device_uuid;
  var device_id;

  infoUpdateResp();

  infoUpdateResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        device_uuid = json['returnData']['device_uuid'],
        device_id = json['returnData']['device_id'],
        super.fromJson(json);
}

class contentQueryResp extends commonResp{
  var cnts;
  var title;
  var message;
  var status_time;
  var content_type;
  var content;

  contentQueryResp();

  contentQueryResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        title = json['returnData']['title'],
        message = json['returnData']['message'],
        status_time = json['returnData']['status_time'],
        content_type = json['returnData']['content_type'],
        content = json['returnData']['content'],
        super.fromJson(json);
}

class messageQueryResp extends commonResp{
  var cnts;
  List<messageQueryRows> ?rows;

  messageQueryResp();

  messageQueryResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        rows = (json['returnCode'] != '0000') ? null : (json['returnData']['rows'] as List)
            .map((json) => new messageQueryRows.fromJson(json))
            .toList(),
        super.fromJson(json);
}

class messageQueryRows {
  var message_id;
  var is_private;
  var category;
  var title;
  var message;
  var param;
  var status_time;
  var date;
  var time;
  var is_read;

  messageQueryRows({this.message_id, this.is_private, this.category, this.title, this.message, this.param, this.status_time, this.date, this.time, this.is_read});

  factory messageQueryRows.fromJson(Map<String, dynamic> json) {
    return messageQueryRows(
        message_id : json['message_id'],
        is_private : json['is_private'],
        category : json['category'],
        title : json['title'],
        message : json['message'],
        param : json['param'],
        status_time : json['status_time'],
        date : json['date'],
        time : json['time'],
        is_read : json['is_read']
    );
  }
}

class statusQueryResp extends commonResp{
  var is_receive;
  var enable_curfew;
  var start_time;
  var end_time;
  var cnts;
  List<statusQueryRows> ?rows;

  statusQueryResp();

  statusQueryResp.fromJson(Map<String, dynamic> json)
      : is_receive = json['returnData']['is_receive'],
        enable_curfew = json['returnData']['enable_curfew'],
        start_time = json['returnData']['start_time'],
        end_time = json['returnData']['end_time'],
        cnts = json['returnData']['cnts'],
        rows = (json['returnCode'] != '0000') ? null : (json['returnData']['rows'] as List)
            .map((json) => new statusQueryRows.fromJson(json))
            .toList(),
        super.fromJson(json);
}

class statusQueryRows {
  var is_private;
  var category;
  var desc;
  var push_status;

  statusQueryRows({this.is_private, this.category, this.desc, this.push_status});

  factory statusQueryRows.fromJson(Map<String, dynamic> json) {
    return statusQueryRows(
        is_private : json['is_private'],
        category : json['category'],
        desc : json['desc'],
        push_status : json['push_status']
    );
  }

  Map<String, dynamic> toJson() => {
    'is_private': is_private,
    'category': category,
    'push_status': push_status,
  };
}

class unReadCountResp extends commonResp{
  var public_cnts;
  var private_cnts;
  var total_cnts;
  List<unReadCountRows> ?rows;

  unReadCountResp();

  unReadCountResp.fromJson(Map<String, dynamic> json)
      : public_cnts = json['returnData']['public_cnts'],
        private_cnts = json['returnData']['private_cnts'],
        total_cnts = json['returnData']['total_cnts'],
        rows = (json['returnCode'] != '0000') ? null : (json['returnData']['rows'] as List)
            .map((json) => new unReadCountRows.fromJson(json))
            .toList(),
        super.fromJson(json);
}

class unReadCountRows {
  var category;
  var count;
  var is_private;

  unReadCountRows({this.category, this.count, this.is_private});

  factory unReadCountRows.fromJson(Map<String, dynamic> json) {
    return unReadCountRows(
        category : json['category'],
        count : json['count'],
        is_private : json['is_private']
    );
  }
}

class bindingQueryResp extends commonResp{
  var cnts;
  List<bindingDevice> ?device;
  List<bindingDomainKey> ?domain_key;

  bindingQueryResp();

  bindingQueryResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        device = (json['returnData']['device'] as List) == null ? null : (json['returnData']['device'] as List)
            .map((json) => new bindingDevice.fromJson(json))
            .toList(),
        domain_key = (json['returnData']['domain_key'] as List) == null ? null : (json['returnData']['domain_key'] as List)
            .map((json) => new bindingDomainKey.fromJson(json))
            .toList(),
        super.fromJson(json);
}

class bindingDevice {
  var serial_no;
  var domain_key;

  bindingDevice({this.serial_no, this.domain_key});

  factory bindingDevice.fromJson(Map<String, dynamic> json) {
    return bindingDevice(
        serial_no : json['serial_no'],
        domain_key : json['domain_key']
    );
  }
}

class bindingDomainKey {
  var serial_no;
  var device_uuid;

  bindingDomainKey({this.serial_no, this.device_uuid});

  factory bindingDomainKey.fromJson(Map<String, dynamic> json) {
    return bindingDomainKey(
        serial_no : json['serial_no'],
        device_uuid : json['device_uuid']
    );
  }
}
