library push_sdk;

import 'dart:convert';
import 'dart:io';
import 'package:device_info/device_info.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'package:push_sdk/global.dart';
import 'package:push_sdk/service/local_data_helper.dart';
import 'package:push_sdk/service/push_api.dart';
import 'package:flutter/services.dart' show rootBundle;

/// APP啟動先執行
Init() async {
 final dataHelper = DataHelper.instance;
 dataHelper.getStorageData();

 await getAppInfo();
 await getApiConnInfo();

 var pushapi = pushApi.instance;
 if(Globals.device_id == "") {
  // 首裝
  pushapi.PushDeviceGetUUID();
 } else {
  // 更新使用時間
  pushapi.PushDeviceInfoUpdate(domain_key: Globals.domain_key, token: Globals.token);
 }
}

/// 取得APP資訊
getAppInfo() async {
 PackageInfo packageInfo = await PackageInfo.fromPlatform();
 Globals.appName = packageInfo.appName;
 Globals.appVersion = packageInfo.version;
 Globals.osVersion = Platform.isIOS
     ? (await DeviceInfoPlugin().iosInfo).systemVersion
     : (await DeviceInfoPlugin().androidInfo).version.release;
}

/// 取得連線資訊
getApiConnInfo() async {
 Map jsonMap = await rootBundle
     .loadStructuredData('assets/appsettings.json', (String s) async {
  return json.decode(s);
 });

 Globals.app_id = jsonMap["app_id"] ?? "";
 Globals.app_key = jsonMap["app_key"] ?? "";
 Globals.GWUrl = jsonMap["api_url"] ?? "";
}



