import 'package:push_sdk/global.dart';
import 'package:shared_preferences/shared_preferences.dart';

class DataHelper {
  //Singleton 單例模式，確保一個類別只有一個實例
  DataHelper._privateConstructor();
  static final DataHelper instance = DataHelper._privateConstructor();
  static var _prefs;

  // 取得 SharedPreferences 的實例
  Future<SharedPreferences> get prefs async {
    if (_prefs != null) return _prefs;
    await _initPrefs();
    return _prefs;
  }

  // 初始化
  _initPrefs() async {
    _prefs = await SharedPreferences.getInstance();
  }

  /// 取得目前已落地的資料
  getStorageData() async {
    SharedPreferences prefs = await instance.prefs;
    Globals.device_id = prefs.getString("device_id") ?? "";
    Globals.device_uuid = prefs.getString("device_uuid") ?? "";
    Globals.domain_key = prefs.getString("domain_key") ?? "";
    Globals.token = prefs.getString("token") ?? "";
    Globals.stamp = prefs.getString("stamp") ?? "";
  }

  /// 清除目前已落地的資料
  clearStorageData() async{
    SharedPreferences prefs = await instance.prefs;
    prefs.remove("device_id");
    prefs.remove("domain_key");
    prefs.remove("token");
    prefs.remove("stamp");
    prefs.remove("stamp");
    getStorageData();
  }

  getData(String key) async {
    SharedPreferences prefs = await instance.prefs;
    return prefs.getString(key);
  }

  setData(String key, String data) async {
    SharedPreferences prefs = await instance.prefs;
    return prefs.setString(key,data);
  }

  removeData(String key) async {
    SharedPreferences prefs = await instance.prefs;
    return prefs.remove(key);
  }
}
